@@ -38,7 +38,7 @@
 #' # Pass in curl options
 #' library("httr")
 #' occ_get(key=766766824, config=verbose())
-#' occ_get(key=766766824, config=progress())
+#' # occ_get(key=766766824, config=progress())
 #' }
 
 occ_get <- function(key=NULL, return='all', verbatim=FALSE, fields='minimal', ...) {
@@ -53,7 +53,7 @@ occ_get <- function(key=NULL, return='all', verbatim=FALSE, fields='minimal', ..
     } else {
       url <- sprintf('%s/occurrence/%s', gbif_base(), x)
     }
-    gbif_GET(url, list(), FALSE, ...)
+    gbif_GET(url, NULL, FALSE, ...)
   }
 
   # Get data
