@@ -2,7 +2,8 @@
 #'
 #' @export
 #'
-#' @param .data Output from a call to \code{occ_search}
+#' @param .data Output from a call to \code{occ_search}, but only if \code{return="all"},
+#' or \code{return="data"}, otherwise function stops with error
 #' @param ... Named parameters to only get back (e.g., cdround), or to remove (e.g. -cdround).
 #' @param mutate (character) One of:
 #' \itemize{
@@ -36,7 +37,7 @@
 #' # compare out data to after occ_issues use
 #' (out <- occ_search(limit=100))
 #' out %>% occ_issues(cudc)
-#' 
+#'
 #' # Parsing output by issue
 #' (res <- occ_search(geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))', limit = 50))
 #'
@@ -70,9 +71,13 @@
 #' }
 
 occ_issues <- function(.data, ..., mutate = NULL) {
-  
+
   stopifnot(is(.data, "gbif"))
-  tmp <- .data$data
+  if ("data" %in% names(.data)) {
+    tmp <- .data$data
+  } else {
+    tmp <- .data
+  }
 
   if (!length(dots(...)) == 0) {
     filters <- parse_input(...)
@@ -95,8 +100,12 @@ occ_issues <- function(.data, ..., mutate = NULL) {
     }
   }
 
-  .data$data <- tmp
-  return( .data )
+  if ("data" %in% names(.data)) {
+    .data$data <- tmp
+    return( .data )
+  } else {
+    return( tmp )
+  }
 }
 
 mutate_iss <- function(w){
