@@ -8,7 +8,7 @@ test_that("type query returns the correct class", {
 })
 
 
-# Fulltext search for all datasets having the word "amsterdam" somewhere in 
+# Fulltext search for all datasets having the word "amsterdam" somewhere in
 # its metadata (title, description, etc).
 test_that("search query returns the correct class", {
   skip_on_cran()
@@ -30,6 +30,6 @@ test_that("limited search returns the correct class", {
 test_that("limited fields query returns the correct class", {
   skip_on_cran()
   tt <- dataset_suggest(type="OCCURRENCE", description=TRUE)
-  expect_is(tt, "character")
+  expect_is(tt, "list")
   expect_is(tt[[1]], "character")
 })
