@@ -69,8 +69,8 @@ test_that("name_usage related route works", {
   rte4a <- name_usage(key = 5135787, data = 'related')
   expect_is(rte4, "list")
   expect_is(rte4a, "list")
-  expect_null(rte4$meta)
-  expect_null(rte4a$meta)
+  expect_is(rte4$meta, "data.frame")
+  expect_is(rte4a$meta, "data.frame")
   expect_is(rte4$data, "data.frame")
   expect_is(rte4a$data, "data.frame")
 })
