@@ -1,30 +1,31 @@
 context("occ_count")
 
-a <- occ_count(basisOfRecord='OBSERVATION')
-b <- occ_count(georeferenced=TRUE)
-c <- occ_count(year=2012)
-d <- occ_count(type='schema')
-e <- occ_count(type='countries')
-f <- occ_count(type='year', from=2000, to=2012)
+test_that("occ_count", {
+  skip_on_cran()
 
-test_that("returns the correct class", {
+  a <- occ_count(basisOfRecord='OBSERVATION')
+  b <- occ_count(georeferenced=TRUE)
+  c <- occ_count(year=2012)
+  d <- occ_count(type='schema')
+  e <- occ_count(type='countries')
+  f <- occ_count(type='year', from=2000, to=2012)
+  
+  # returns the correct class
   expect_is(a, "numeric")
   expect_is(b, "numeric")
   expect_is(c, "numeric")
   expect_is(d, "list")
   expect_is(e, "list")
   expect_is(f, "list")
-})
 
-test_that("returns the correct value", {
+  # returns the correct value
   expect_equal(names(d[[1]]$dimensions[[1]]), c("key","type"))
   expect_equal(names(e)[1], "UNITED_STATES")
-})
 
-test_that("returns the correct dimensions", {
+  # returns the correct dimensions
   expect_equal(length(a), 1)
   expect_equal(length(b), 1)
   expect_equal(length(c), 1)
   expect_equal(length(d), 42)
   expect_equal(length(e), 249)
-})
\ No newline at end of file
+})
